var a00479 =
[
    [ "cppu::PropertySetMixinImpl", "a01886.html", "a01886" ],
    [ "cppu::PropertySetMixinImpl::BoundListeners", "a01890.html", "a01890" ],
    [ "cppu::PropertySetMixin&lt; T &gt;", "a01894.html", "a01894" ]
];